==> epiphany-2.28.2p0.tgz: include/epiphany/2.28/epiphany/ephy-embed-type-builtins.h <==

/* Generated data (by glib-mkenums) */

#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
#error Only <epiphany/epiphany.h> can be included directly.
#endif

#ifndef EPHY_EMBED_TYPE_BUILTINS_H
#define EPHY_EMBED_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-adblock.h --- */
#define EPHY_TYPE_URI_CHECK_TYPE ad_uri_check_type_get_type()
GType ad_uri_check_type_get_type (void);

/* --- ephy-embed-event.h --- */
#define EPHY_TYPE_EMBED_EVENT_CONTEXT ephy_embed_event_context_get_type()
GType ephy_embed_event_context_get_type (void);

/* --- ephy-embed-persist.h --- */
#define EPHY_TYPE_EMBED_PERSIST_FLAGS ephy_embed_persist_flags_get_type()
GType ephy_embed_persist_flags_get_type (void);

/* --- ephy-permission-manager.h --- */
#define EPHY_TYPE_PERMISSION ephy_permission_get_type()
GType ephy_permission_get_type (void);

/* --- ephy-web-view.h --- */
#define EPHY_TYPE_WEB_VIEW_NAVIGATION_FLAGS ephy_web_view_navigation_flags_get_type()
GType ephy_web_view_navigation_flags_get_type (void);
#define EPHY_TYPE_WEB_VIEW_NET_STATE ephy_web_view_net_state_get_type()
GType ephy_web_view_net_state_get_type (void);
#define EPHY_TYPE_WEB_VIEW_CHROME ephy_web_view_chrome_get_type()
GType ephy_web_view_chrome_get_type (void);
#define EPHY_TYPE_WEB_VIEW_PRINT_PREVIEW_NAV_TYPE ephy_web_view_print_preview_nav_type_get_type()
GType ephy_web_view_print_preview_nav_type_get_type (void);
#define EPHY_TYPE_WEB_VIEW_SECURITY_LEVEL ephy_web_view_security_level_get_type()
GType ephy_web_view_security_level_get_type (void);
#define EPHY_TYPE_WEB_VIEW_DOCUMENT_TYPE ephy_web_view_document_type_get_type()
GType ephy_web_view_document_type_get_type (void);
G_END_DECLS

#endif /* EPHY_EMBED_TYPE_BUILTINS_H */

/* Generated data ends here */

==> epiphany-3.4.2.tgz: include/epiphany/3.4/epiphany/ephy-embed-type-builtins.h <==



#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
#error Only <epiphany/epiphany.h> can be included directly.
#endif

#ifndef EPHY_EMBED_TYPE_BUILTINS_H
#define EPHY_EMBED_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-adblock.h --- */
#define EPHY_TYPE_URI_CHECK_TYPE ad_uri_check_type_get_type()
GType ad_uri_check_type_get_type (void);

/* --- ephy-download.h --- */
#define EPHY_TYPE_DOWNLOAD_ACTION_TYPE ephy_download_action_type_get_type()
GType ephy_download_action_type_get_type (void);

/* --- ephy-embed-shell.h --- */
#define EPHY_TYPE_EMBED_SHELL_MODE ephy_embed_shell_mode_get_type()
GType ephy_embed_shell_mode_get_type (void);

/* --- ephy-permission-manager.h --- */
#define EPHY_TYPE_PERMISSION ephy_permission_get_type()
GType ephy_permission_get_type (void);

/* --- ephy-web-view.h --- */
#define EPHY_TYPE_WEB_VIEW_NAVIGATION_FLAGS ephy_web_view_navigation_flags_get_type()
GType ephy_web_view_navigation_flags_get_type (void);
#define EPHY_TYPE_WEB_VIEW_CHROME ephy_web_view_chrome_get_type()
GType ephy_web_view_chrome_get_type (void);
#define EPHY_TYPE_WEB_VIEW_SECURITY_LEVEL ephy_web_view_security_level_get_type()
GType ephy_web_view_security_level_get_type (void);
#define EPHY_TYPE_WEB_VIEW_DOCUMENT_TYPE ephy_web_view_document_type_get_type()
GType ephy_web_view_document_type_get_type (void);
#define EPHY_TYPE_WEB_VIEW_ERROR_PAGE ephy_web_view_error_page_get_type()
GType ephy_web_view_error_page_get_type (void);
G_END_DECLS

#endif /* EPHY_EMBED_TYPE_BUILTINS_H */
